@@ -66,6 +66,10 @@ func (c *Client) AuthSource() gitlab.AuthSource {
 	return c.authSource
 }
 
+func (c *Client) BaseURL() string {
+	return c.baseURL
+}
+
 // Lab returns the initialized GitLab client.
 func (c *Client) Lab() *gitlab.Client {
 	return c.gitlabClient
@@ -329,13 +333,19 @@ func NewClientFromConfig(repoHost string, cfg config.Config, isGraphQL bool, use
 			}
 			return gitlab.OAuthTokenSource{TokenSource: ts}, nil
 		}
+	case token != "":
+		// Check for PAT first since it's more common than job tokens
+		newAuthSource = func(*http.Client) (gitlab.AuthSource, error) {
+			return gitlab.AccessTokenAuthSource{Token: token}, nil
+		}
 	case jobToken != "":
 		newAuthSource = func(*http.Client) (gitlab.AuthSource, error) {
 			return gitlab.JobTokenAuthSource{Token: jobToken}, nil
 		}
 	default:
+		// NOTE: use an unauthenticated client.
 		newAuthSource = func(*http.Client) (gitlab.AuthSource, error) {
-			return gitlab.AccessTokenAuthSource{Token: token}, nil
+			return gitlab.Unauthenticated{}, nil
 		}
 	}
 
