@@ -62,7 +62,7 @@ func NewCmdGenerate(f cmdutils.Factory) *cobra.Command {
 		Prerequisites:
 
 		- You must have a SSH key pair in RSA, ed25519, or ECDSA format.
-		- You have enabled DPoP for your account, as described in the [GitLab documentation.](https://docs.gitlab.com/user/profile/personal_access_tokens/#require-dpop-headers-with-personal-access-tokens)
+		- You have [enabled DPoP for your account](https://docs.gitlab.com/user/profile/personal_access_tokens/#use-dpop-with-personal-access-tokens).
 
 		Use the JWT in combination with a Personal Access Token (PAT) to authenticate to
 		the GitLab API. Your JWT remains valid for 5 minutes. After it expires, you must
