@@ -64,7 +64,7 @@ func NewCmdExport(f cmdutils.Factory, runE func(opts *options) error) *cobra.Com
 			$ glab variable export --output export
 		`),
 		Annotations: map[string]string{
-			mcpannotations.Safe: "true",
+			mcpannotations.Exclude: "true",
 		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := opts.complete(cmd); err != nil {
@@ -112,7 +112,7 @@ func (o *options) run() error {
 	}
 
 	// NOTE: this command can not only be used for projects,
-	// so we have to manually check for the base repo, it it doesn't exist,
+	// so we have to manually check for the base repo, if it doesn't exist,
 	// we bootstrap the client with the default hostname.
 	var repoHost string
 	if baseRepo, err := o.baseRepo(); err == nil {
